from fastapi import FastAPI, HTTPException
from pydantic import BaseModel
import uvicorn
import sys
import click

app = FastAPI()

class Item(BaseModel):
    name: str
    description: str | None = None

@app.get("/items/{item_id}")
def read_item(item_id: int):
    return {"item_id": item_id, "name": f"Item {item_id}"}

@app.post("/items/")
def create_item(item: Item):
    if not item.name:
        raise HTTPException(status_code=400, detail="Name is required")
    return {"item": item}

@click.command()
@click.option('--host', default='127.0.0.1', help='Host to run the server on')
@click.option('--port', default=8000, help='Port to run the server on')
def cli(host, port):
    """Starte die FastAPI Standalone Application."""
    uvicorn.run("test-app.main:app", host=host, port=port, reload=False)
